(* ::Package:: *)

(* Name of package : FunctionsMathematica6 *)

(* Description of following package : 
    the package consists of this parts, 
    OFFSETS                 . . .  contains the functions for classical and general offset, and for reparametrization
    DIFFERENTIAL GEOMETRY   . . .  contains the main functions, which are describing basic features of Differential Geometry,
    GEOMETRY (ConicSection) . . .  contains the functions for investigating conicsection
    ALGORITHMS              . . .  contains only parts of algorithm which can detect the crucial problem in milling - undercut*)

(* Author : Marek BYRTUS, ZCU-FAV, KMA, Plzen, 
   Email  : byrtus@kma.zcu.cz *)


BeginPackage["FunctionsMathematica6`",{"VectorFieldPlots`","PlotLegends`"}]

(*
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 ------------ OFFSETS (2D, 3D)---------------------------------------------------------------------------------------------------------------------------------------------------
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
ClassicalOffset2D::usage =\
"This function is computing the classical offset for given curve. The usage is is \!\(\*
StyleBox[\"ClassicalOffset2D\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,
 where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric expression of curve, \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametr and \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is distance \[Delta] ";\

GeneralOffset2D::usage = \
"This function is computing a plain general offset. The usage is \!\(\*
StyleBox[\"GeneralOffset2D\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), \n
 where : \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) ... curve given by parametric expression {.,.} ,
         \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) ... curve give by parametric expression {.,.}
 and the result is in the parameters of first curve.";\

Reparametrization2D::usage = \
"This function makes raprametrization. The usage is \!\(\*
StyleBox[\"Reparametrization2D\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,\n
  where : \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) ... curve given by parametric expression {.,.} ,
          \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) ... curve give by parametric expression {.,.}
 and  the result is parametric expression in the form {.,.}, which is describing the first curve, but in the parameters of 
 the second curve.";\

ClassicalOffset3D::usage =\
"This function is computing the classical offset for given surface. The usage is The usage is is \!\(\*
StyleBox[\"ClassicalOffset3D\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,
 where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric expression of surface in the form , \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters in the form {.,.} and \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is distance \[Delta] ";\


GeneralOffset3D::usage = \
"This function is computing a three-dimensional general offset. The usage is \!\(\*
StyleBox[\"GeneralOffset3D\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), \n
 where : \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) ... surface given by parametric expression {.,.,.} ,
         \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) ... surface give by parametric expression {.,.,.}
 and the result is in the parameters of first curve.";\


Reparametrization3D::usage = \
"This function makes raprametrization. The usage is \!\(\*
StyleBox[\"Reparametrization3D\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,\n
  where : \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) ... surface given by parametric expression {.,.,.} ,
          \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) ... surface give by parametric expression {.,.,.}
 and  the result is parametric expression in the form {.,.,.}, which is describing the first surface,
 but in the parameters of the second curve.";\

(*
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 ------------ DIFFERENTIAL GEOMETRY ---------------------------------------------------------------------------------------------------------------------------------------------
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
FirstFundamentalForm::usage = \
"This function is computing the first fundamental form of surface. The usage is
 \!\(\*
StyleBox[\"FirstFundamentalForm\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"{\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"}\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric expression of given surface and \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\),\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters.";\

SecondFundamentalForm::usage = \
"This function is computing the second fundamental form of surface. The usage is
 \!\(\*
StyleBox[\"SecondFundamentalForm\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"{\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"}\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric expression of given surface and \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\),\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters.";\

TangentsOfSurface::usage = \
"This function is computing two tangent vector denpending on parametrization. The usage is
 \!\(\*
StyleBox[\"TangentsOfSurface\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"{\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"}\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\)where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric expression of given surface and \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\),\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters.";\

NormalOfSurface::usage = \
"This function is computing normal vector of given surface denpending on its parametrization. The usage is
 \!\(\*
StyleBox[\"NormalOfSurface\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"{\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"}\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\)where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric expression of given surface and \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\),\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters.";\

NormOfVector::usage =\
"This function is computing the norm of given vector. The usage is \!\(\*
StyleBox[\"NormOfVector\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is two-dimensional or 
three-dimensional vector.";\

DupinIndicatrix::usage = \
"This function is computing Dupin Indicatrix. The output is graphical format and the usage is
 \!\(\*
StyleBox[\"DupinIndicatrix\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"e\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"f\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)is parametric expression of surface, \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters and it has to be written 
 in the form {.,.}, \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is arbitrary  point in parametric plane, \!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is x-axes range in the form {lower,upper}, \!\(\*
StyleBox[\"e\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is y-axes range in
 the  form {lower,upper} and \!\(\*
StyleBox[\"f\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the hue-color of Dupin Indicatrix form the interval <0,1>.";\
                                 

DupinIndicatrixEquations::usage = \
"This function is computing Dupin Indicatrix. The output is two equations of Dupin Indicatrix, which are two equations
 of conic section in the form \!\(\*
StyleBox[\"f\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"x\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"y\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"0\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\). The usage is  \!\(\*
StyleBox[\"DupinIndicatrixEquations\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric expression of given surface, 
 \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters and it has to be written 
 in the form {.,.}, \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is arbitrary  point in parametric plane and \!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are new two variables written in the form {.,.}.";\

DupinIndicatrixEquationsWithoutZero::usage = \
"This function is computing Dupin Indicatrix. The output is two equations of Dupin Indicatrix, which are two equations
 of conic section in the form \!\(\*
StyleBox[\"f\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"x\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"y\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\). The usage is  \!\(\*
StyleBox[\"DupinIndicatrixEquationsWithoutZero\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric
  expression of given surface, 
 \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters and it has to be written 
 in the form {.,.}, \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is arbitrary  point in parametric plane and \!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are new two variables written in the form {.,.}.";\

GeneralDupinIndicatrixEquations::usage =\
"This function is computing general equations of Dupin Indicatrix. The usage is in the form 
 \!\(\*
StyleBox[\"GeneralDupinIndicatrixEquations\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of given surface, 
 \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters and it has to be written in the form {.,.}, \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)are two new varialbes in the form {.,.}. The coefficients of 
 equations \!\(\*
StyleBox[\"f\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"x\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"y\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"=\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"0\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"  \",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)are depending on parameters.\!\(\*
StyleBox[\" \",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)";\

GeneralDupinIndicatrixEquationsWithoutZero::usage =\
"This function is computing general equations of Dupin Indicatrix. The usage is in the form 
 \!\(\*
StyleBox[\"GeneralDupinIndicatrixEquationsWithoutZero\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of given surface, 
 \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters and it has to be written in the form {.,.}, \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)are two new varialbes in the form {.,.}. The coefficients of 
 equations \!\(\*
StyleBox[\"f\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"(\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"x\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\",\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"y\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\")\",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)\!\(\*
StyleBox[\"  \",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)are depending on parameters.\!\(\*
StyleBox[\" \",\nFontFamily->\"Arial\",\nFontWeight->\"Bold\",\nFontSlant->\"Italic\"]\)";\


ParametricPlane::usage = \
"This function draws the parametric plane of given surface. In the graphisc are demonstrated elliptic, parabolic
 and hyperbolic points. The usage is \!\(\*
StyleBox[\"ParametricPlane\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"e\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of given surface,
 \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) and \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters, \!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) and \!\(\*
StyleBox[\"e\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are the x-axis and y-axis range.";\
               
ParametricPlaneLegend::usage = \
"This function draws the parametric plane of given surface by the legend. In the graphisc are demonstrated elliptic, parabolic
 and hyperbolic points. The usage is \!\(\*
StyleBox[\"ParametricPlane\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"e\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of given surface,
 \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) and \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters, \!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) and \!\(\*
StyleBox[\"e\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are the x-axis and y-axis range.";\

HessMatrix::usage = \
"This function is computing Hess matrix. The usage is \!\(\*
StyleBox[\"HessMatrix\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,  where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of given surface, 
 \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters and it has to be written in the form {.,.}. "\

ConvexSurface::usage = \
"This function draws the graphics of prametric plane of the given surface. In the graphics are show the domains where is the 
 surface convex. The usage of this function is  \!\(\*
StyleBox[\"ConvexSurface\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"p\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a1\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a2\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\) where \!\(\*
StyleBox[\"p\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of 
 given surface, \!\(\*
StyleBox[\"a1\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) and \!\(\*
StyleBox[\"a2\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters, \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) and \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are x-axis and y-axis range and \!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the number from interval <0,1>, 
 which represents  the GrayLevel."

ConvexSurfaceInequality::usage = \
"This function writes the inequalities for parameters of given surface,  where will be convex domains. The usage of this 
 function is \!\(\*
StyleBox[\"ConvexSurfaceInequality\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"p\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"p\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of given surface, 
 \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters and it has to be written in the form {.,.}."\

ConcaveSurface::usage = \
"This function draws the graphics of prametric plane of the given surface. In the graphics are show the domains where is the 
 surface convex. The usage of this function is  \!\(\*
StyleBox[\"ConcaveSurface\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"p\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a1\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a2\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\) where \!\(\*
StyleBox[\"p\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of 
 given surface, \!\(\*
StyleBox[\"a1\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) and \!\(\*
StyleBox[\"a2\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters, \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) and \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are x-axis and y-axis range and \!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the number from interval <0,1>, 
 which represents  the GrayLevel."

ConcaveSurfaceInequality::usage = \
"This function writes the inequalities for parameters of given surface,  where will be concave domains. The usage of this 
 function is \!\(\*
StyleBox[\"ConcaveSurfaceInequality\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"p\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"p\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of given surface, 
 \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters and it has to be written in the form {.,.}."\

ConvexConcaveSurface::usage = \
"diskuze, vsech oblasti na plose"\

FirstCurvature::usage = \
"This function is computing the first curvature of given curve. The result is general and the usage of this function is
 \!\(\*
StyleBox[\"FirstCurvature\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)  is parametric expression of given curve (plane on three-dimensional) and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parameter."\

SecondCurvature::usage = \
"This function computes the second curvature of given curve. The result is general and the usage of this function is
 \!\(\*
StyleBox[\"SecondCurvature\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)  is parametric expression of given curve (plane on three-dimensional) and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parameter."\

GaussCurvature::usage = \
"This function  computes the Gauss curvature of given surface. The result is general and the usage of this function is
 \!\(\*
StyleBox[\"GaussCurvature\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)  is parametric expression of given surface  and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters, which have to be written 
 in the form {.,.}."\

MiddleCurvature::usage = \
"This function  computes the middle curvature of given surface. The result is general and the usage of this function is
 \!\(\*
StyleBox[\"MiddleCurvature\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)  is parametric expression of given surface  and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters, which have to be written 
 in the form {.,.}."\

ExtremalMiddleCurvature::usage = \
"This function  computes the extremes of the middle curvature. The result are values of parameters. The usage is 
 \!\(\*
StyleBox[\"Extremal\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"MiddleCurvature\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)  is parametric expression of given surface  and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters, which have to be written 
 in the form {.,.}."\

FrenetTrihedron::usage = \
"This function draws the Frenet Trihedron of the given curve in a given point. The usage is \!\(\*
StyleBox[\"FrenetTrihedron\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[
StyleBox[
RowBox[{
StyleBox[\"a\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]], \"_\"}]],\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[
StyleBox[
RowBox[{
StyleBox[\"b\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]], \"_\"}]],\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[
StyleBox[
RowBox[{
StyleBox[\"c\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]], \"_\"}]],\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[
StyleBox[
RowBox[{
StyleBox[\"d\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]], \"_\"}]],\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) , where 
 \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric expression of given curve (plain or three-dimensional), \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametr of the curve, \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is value of parameter
 and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)is the range of parameter."\

MinimalFirstCurvature::usage = \
"This function  computes minimum of the first curvature of the given curve. The usage is mainly for rational parametric
 expression  of curve and it is in the form  \!\(\*
StyleBox[\"Minimal\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"FirstCurvature\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\), where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)  is parametric expression of the given curve 
 (plane on three-dimensional) and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parameter. The result is number of minimum of the first curvature."\

PointsOfMinimalFirstCurvature::usage = \
"This function computes the minimum of the first curvature and it draw a graphics where are the curve and the point with 
 minimal first curvature. The usage is \!\(\*
StyleBox[\"PointsOfMinimalFirstCurvature\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric expression of curve 
 (plain or three-dimensional) and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametr of the given curve."\
(*
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 ------------ GEOMETRY - ConicSection --------------------------------------------------------------------------------------------------------------------------------------------------------
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
UnitGivenVector::usage = \
"This function is computing unit vector og given vector. The usage is \!\(\*
StyleBox[\"UnitGivenVector\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[
StyleBox[
RowBox[{
StyleBox[\"a\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]], \"_\"}]],\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric
 expression of curve (plain or three-dimensional)."

MatrixOfConicSection::usage = \
"This function computes the matrix (3\[Times]3) for the given conic section. The usage is \!\(\*
StyleBox[\"MatrixOfConicSection\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)
 , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the equation of conic section and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are variables in the form {.,.}.";\

CoefficientsOfConicSection::usage = \
"This function computes the matrix the coefficients for the given conic section. The usage is 
 \!\(\*
StyleBox[\"CoefficientsOfConicSection\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the equation of the  given conic section and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are variables in 
 the form {.,.}.";\

CentreOfConicSectionDiscussion::usage = \
"This function discusses how many centres has the given conic section. The usage is
 \!\(\*
StyleBox[\"CentresOfConicSectionDiscussion\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the equation of the  given conic section and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are variables in 
 the form {.,.}.";\

CentreOfConicSection::usage = \
"This function computes the  centres of the given conic section. The usage is
 \!\(\*
StyleBox[\"CentresOfConicSection\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the equation of the  given conic section and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are variables in 
 the form {.,.}.";\

PlotOfConicSection::usage = \
"This function draw a given conic section. The usage is \!\(\*
StyleBox[\"PlotOfConicSection\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"e\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) , where 
 where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the equation of the  given conic section and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are variables in 
 the form {.,.}, \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is x-axes range, \!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is y-axes range and \!\(\*
StyleBox[\"e\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is a hue-color from interval <0,1>.";\

AsymptoticDirectionOfConicSection::usage = \
"This function computes the  asymptotic direction of the given conic section. The usage is
 \!\(\*
StyleBox[\"AsymptoticDirectionOfConicSection\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the equation of the  given conic section and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are variables in 
 the form {.,.}.";\


PlotOfAsymptoteOfConicSection::usage = \
"This function draw a asymptotes of given conic section. The usage is \!\(\*
StyleBox[\"PlotOfAsymptoteOfConicSection\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,  
 where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the equation of the  given conic section and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are variables in 
 the form {.,.}, \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parameter range and \!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)  is a hue-color from interval <0,1>.";\

MainDirectionOfConicSection::usage = \
"This function computes the  main direction of the given conic section. The usage is
 \!\(\*
StyleBox[\"MainDirectionOfConicSection\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\" \",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the equation of the  given conic section and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are variables in 
 the form {.,.}.";\

PlotOfMainDirectionOfConicSection::usage = \
"This function draw a main direction of given conic section. The usage is \!\(\*
StyleBox[\"PlotOfMainDirectionOfConicSection\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,
 where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the equation of the  given conic section and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are variables in 
 the form {.,.}, \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parameter range and \!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)  is a hue-color from interval <0,1>.";\

TransformationOfConicSection::usage = \
"This function transfers a given  conic section from general position  to the special position, where are
 the main direction parallel with  x-axis and y-axis. The usage is \!\(\*
StyleBox[\"TransformationOfConicSection\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,
 where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the equation of the  given conic section and \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are variables in 
 the form {.,.}.";\

(*
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 ------------ ALGORITMUS (using conic section and differential geometry) --------------------------------------------------------------------------------------------------------
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
HyperbolicPoints::usage = \
"This function returns the domain in parametric plane of surface, where the surface will have  hyperbolic points.
 The usage is \!\(\*
StyleBox[\"HyperbolicPoints\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,  where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of given surface, 
 \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters and it has to be written in the form {.,.}."\

ParabolicPoints::usage = \
"This function returns the domain in parametric plane of surface, where the surface will have parabolic points.
 The usage is \!\(\*
StyleBox[\"ParabolicPoints\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,  where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of given surface, 
 \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters and it has to be written in the form {.,.}."\

EllipticPoints::usage = \
"This function returns the domain in parametric plane of surface, where the surface will have  elliptic points.
 The usage is \!\(\*
StyleBox[\"EllipticPoints\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,  where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric  expression of given surface, 
 \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters and it has to be written in the form {.,.}."\


ConvexDiscussionOfMainDirection::usage = \
"This function makes a discussion of main directions - it writes the domains for given main direction, where this 
 main direction describes convex curve. The usage is \!\(\*
StyleBox[\"ConvexDiscussionOfMainDirection\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[
StyleBox[
RowBox[{
StyleBox[\"a\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]], \"_\"}]],\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\*
StyleBox[\(\!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\)\!\(\*
StyleBox[\"_\",\nFontWeight->\"Bold\"]\)\)]\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[
StyleBox[
RowBox[{
StyleBox[\"c\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]], \"_\"}]],\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) , where \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is 
 parametric expression of given surface, \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters in the dfform {.,.} and \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the set domain given by
 inequalities. "\

IntersectionWithHyperbola::usage = \
"This function computes the intersections of line given by directional vector with Dupin Indicatrixes. The results
 are two reals and two complex intersections. The usage is \!\(\*
StyleBox[\"IntersectionWithHyperbola\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"[\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[
StyleBox[
RowBox[{
StyleBox[\"a\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]], \"_\"}]],\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[
StyleBox[
RowBox[{
StyleBox[\"b\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]], \"_\"}]],\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[
StyleBox[
RowBox[{
StyleBox[\"c\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]], \"_\"}]],\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\",\",\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[
StyleBox[
RowBox[{
StyleBox[\"d\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]], \"_\"}]],\nFontWeight->\"Bold\"]\)\!\(\*
StyleBox[\"]\",\nFontWeight->\"Bold\"]\) ,where
 \!\(\*
StyleBox[\"a\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is parametric expression of the surface, \!\(\*
StyleBox[\"b\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are parameters in the form {.,.}, \!\(\*
StyleBox[\"c\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) is the directional vector 
 and \!\(\*
StyleBox[\"d\",\nFontWeight->\"Bold\",\nFontColor->RGBColor[1., 0.5019607843137255, 0.]]\) are new variables of Dupin Indicatrix (in this case they are hyperbolas) in the form {.,.}. "\
(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)

Begin["FunctionsMathematica6`Private`"]

(*
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 ------------ OFFSETS -----------------------------------------------------------------------------------------------------------------------------------------------------------
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------

-----------------------------------------
---------  2-D --------------------------
-----------------------------------------
*)

ClassicalOffset2D[krivka_,parametr_,delta_]:=
  Module[{},tecna=D[krivka,parametr];
    velikostNormaly=Sqrt[tecna[[1]]^2+tecna[[2]]^2];
    normala1=1/velikostNormaly{tecna[[2]],-tecna[[1]]};
    normala2=1/velikostNormaly{-tecna[[2]],tecna[[1]]};
    KlasOff1=krivka+ delta normala1;
    KlasOff2=krivka+ delta normala2;{KlasOff1,KlasOff2}
    ]
    
    
GeneralOffset2D[b_,a_]:=
Module[{},
    TecnaA=D[a,First[Variables[a]]];
    TecnaB=D[b,First[Variables[b]]];
    NormalaA={-TecnaA[[2]],TecnaA[[1]]};
    NormalaB={-TecnaB[[2]],TecnaB[[1]]};
    reseni= {First[Variables[a]],\[Lambda]}/.
             Solve[NormalaA==\[Lambda] NormalaB,{First[Variables[a]],\[Lambda]}];
    dimense=Dimensions[reseni];
    If[dimense[[1]]==2,
               Print["Two solutions"],
               Print["One solution"]];
    PocetReseni=If[dimense[[1]]==1,
                   ReplaceAll[b-a,Thread[{First[Variables[a]]}->{reseni[[1,1]]}]],
                   {ReplaceAll[b-a,Thread[{First[Variables[a]]}->{reseni[[1,1]]}]],
                    ReplaceAll[b-a,Thread[{First[Variables[a]]}->{reseni[[2,1]]}]]}];
    PocetReseni]



(*
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)  
Reparametrization2D[b_,a_]:=
Module[{},
    TecnaA=D[a,First[Variables[a]]];
    TecnaB=D[b,First[Variables[b]]];
    (*Pomer[[1]]=PomerB,Pomer[[2]]=PomerA*)
    Pomer=
      If[ToString[TecnaB[[2]]]!="0"\[And] ToString[TecnaA[[2]]]!="0",
         {PomerB=TecnaB[[1]]/TecnaB[[2]],
          PomerA=TecnaA[[1]]/TecnaA[[2]]},
        If[ToString[TecnaB[[1]]]!="0"\[And] ToString[TecnaA[[1]]]!="0",
         {PomerB=TecnaB[[2]]/TecnaB[[1]],
          PomerA=TecnaA[[2]]/TecnaA[[1]]},
          text="both ratios are zero"]];
    Parametry=Solve[PomerA==PomerB,Variables[a]];
    vysledek=
      If[Parametry!={{}}\[And]Parametry!={}\[And] ToString[ComplexExpand[Im[First[Variables[a]]/.First[Parametry[[1]]]]]]=="0",
        Module[{},
          Reseni=First[First[Variables[a]]/.Solve[PomerA==PomerB, First[Variables[a]]]];
          Reparametrizace=Simplify[ReplaceAll[a,{First[Variables[a]]->Reseni}]]],
          slovo="Reparametrization doesnt exit"];
 vysledek] 
        
(*
-----------------------------------------
--------- 3-D ---------------------------
-----------------------------------------
*)

ClassicalOffset3D[plocha_,parametry_,delta_]:=
  Module[{},tecna1=D[plocha,parametry[[1]]];tecna2=D[plocha,parametry[[2]]];
    Normala1=Cross[tecna1,tecna2];Normala2=Cross[tecna2,tecna1];
    velikostNormaly=Sqrt[Normala1[[1]]^2+Normala1[[2]]^2+Normala1[[3]]^2];
    JednNormala1=Normala1/velikostNormaly;
    JednNormala2=Normala2/velikostNormaly;
    KlasOffPl1=plocha+ delta JednNormala1;
    KlasOffPl2=plocha+ delta JednNormala2;{KlasOffPl1,KlasOffPl2}]


(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
GeneralOffset3D[b_,a_]:=
Module[{},
    TecnaA1=D[a,Variables[a][[1]]];
    TecnaA2=D[a,Variables[a][[2]]];
    NormalaA=Simplify[Cross[TecnaA1,TecnaA2]];
    TecnaB1=D[b,Variables[b][[1]]];
    TecnaB2=D[b,Variables[b][[2]]];
    NormalaB=Simplify[Cross[TecnaB1,TecnaB2]];
    reseni={Extract[Variables[a],1],Extract[Variables[a],2],\[Lambda]}/.
            Solve[NormalaA==\[Lambda] NormalaB,{Extract[Variables[a],1], Extract[Variables[a],2],\[Lambda]}];
    dimenze=Dimensions[reseni];
    If[dimenze[[1]]==2,
       Print["Two solutions"],
       Print["One solution"]];
    PocetRes=If[dimenze[[1]]==1,
                ReplaceAll[b-a, Thread[{Extract[Variables[a],1],Extract[Variables[a],2]}->{reseni[[1,1]], reseni[[1,2]]}]],
                {ReplaceAll[b-a,Thread[{Extract[Variables[a],1],Extract[Variables[a],2]}->{reseni[[1,1]], reseni[[1,2]]}]],
                 ReplaceAll[b-a,Thread[{Extract[Variables[a],1],Extract[Variables[a],2]}->{reseni[[2,1]], reseni[[2,2]]}]]}];
    Simplify[PocetRes]
    ]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
Reparametrization3D[b_,a_]:=
Module[{},
 TecnaA1=D[a,Variables[a][[1]]];
 TecnaA2=D[a,Variables[a][[2]]];
 NormalaA=Cross[TecnaA1,TecnaA2];
 TecnaB1=D[b,Variables[b][[1]]];
 TecnaB2=D[b,Variables[b][[2]]];
 NormalaB=Cross[TecnaB1,TecnaB2];
 
 If[
    ToString[NormalaA[[3]]]!= "0" \[And] ToString[NormalaB[[3]]]!="0",
      {PomerB={NormalaB[[1]]/NormalaB[[3]], NormalaB[[2]]/NormalaB[[3]]},  
       PomerA={NormalaA[[1]]/NormalaA[[3]],NormalaA[[2]]/NormalaA[[3]]}},
       
      If[ToString[NormalaB[[2]]]!= "0"  \[And] ToString[NormalaA[[2]]] != "0",
         {PomerB={NormalaB[[1]]/NormalaB[[2]], NormalaB[[3]]/NormalaB[[2]]}, 
          PomerA={NormalaA[[1]]/NormalaA[[2]],NormalaA[[3]]/NormalaA[[2]]}},
          
         If[ ToString[NormalaB[[1]]]!= "0" \[And] ToString[NormalaA[[1]]] != "0",
            {PomerB={NormalaB[[2]]/NormalaB[[1]], NormalaB[[3]]/NormalaB[[1]]},           
             PomerA={NormalaA[[2]]/NormalaA[[1]],NormalaA[[3]]/NormalaA[[1]]}},
             text="Both ratios are zero"]]];
             
  Parametry = Solve[PomerA==PomerB,Variables[a]];
  vysledek =
    If[
       Parametry!= {{}} \[And] Parametry != {},
       Module[{}, Reseni=First[Variables[a]/.Solve[PomerA==PomerB,Variables[a]]];Reparametrizace= ReplaceAll[a,{Variables[a][[1]]->Reseni[[1]],Variables[a][[2]]->Reseni[[2]]}]],
       slovo = " Reparametrizace doesnt exist "];
vysledek]


(*
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 ------------ DIFFERENTIAL GEOMETRY ---------------------------------------------------------------------------------------------------------------------------------------------
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)

FirstFundamentalForm[a_,b_]:=
  Module[{},
  Tecna1=D[a,b[[1]]];
  Tecna2=D[a,b[[2]]];
  g11=Tecna1 . Tecna1;
  g12=Tecna1 . Tecna2;
  g21=Tecna2 . Tecna1;
  g22=Tecna2 . Tecna2; 
  g={{g11,g12},{g21,g22}};g]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)  
SecondFundamentalForm[a_,b_]:=
Module[{},
    Tecna1=D[a,b[[1]]];
    Tecna2=D[a,b[[2]]];
    Tecna11=D[Tecna1,b[[1]]];
    Tecna22=D[Tecna2,b[[2]]];
    Tecna12=D[Tecna1,b[[2]]];
    Tecna21=D[Tecna2,b[[1]]];
    Normala1=Cross[Tecna1,Tecna2];
    velikost=Sqrt[Normala1[[1]]^2+Normala1[[2]]^2+Normala1[[3]]^2];
    Normala={Normala1[[1]]/velikost,Normala1[[2]]/velikost,Normala1[[3]]/velikost};
    f11=Normala . Tecna11;
    f12=Normala . Tecna12;
    f21=Normala . Tecna21;
    f22=Normala . Tecna22;
    f={{f11,f12},{f21,f22}};
    Simplify[f]]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
TangentsOfSurface[a_,b_]:=
 Module[{},
  Tecna1=D[a,b[[1]]];
  Tecna2=D[a,b[[2]]];
  {Tecna1,Tecna2}]
  
(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)  
NormalOfSurface[a_,b_]:=
  Module[{},
   Tecna1=D[a,b[[1]]];
   Tecna2=D[a,b[[2]]];
   Normala=Cross[Tecna1,Tecna2];
  Normala]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)  
NormOfVector[a_]:=
  Module[{},
    soucet=0;
    Do[soucet+=(a[[i]])^2,{i,1,Length[a]}];
    velikost=Sqrt[soucet];
  velikost]  



(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)  
DupinIndicatrix[a_,b_,c_,d_,e_,f_]:=
Module[{},
  Forma2=SecondFundamentalForm[a,b];
  Kuzelosecka=Forma2[[1,1]] (du)^2+ 2 Forma2[[1,2]] (du) (dv) + Forma2[[2,2]](dv)^2/.Thread[b->c];
  Graf1=ContourPlot[Kuzelosecka==1,{du,d[[1]],d[[2]]},{dv,e[[1]],e[[2]]},AspectRatio->1/GoldenRatio,ContourStyle->{Hue[f]}];
  Graf2=ContourPlot[Kuzelosecka==-1,{du,d[[1]],d[[2]]},{dv,e[[1]],e[[2]]},AspectRatio->1/GoldenRatio,ContourStyle->{Hue[f]}];
  Graf3=Graphics[{GrayLevel[1],PointSize[0.0001],Point[{0,0}]}];
  If[ToString[Head[Graf1]]=="Graphics" \[And] ToString[Head[Graf2]]=="Graphics",
     Show[Graf1,Graf2,PlotRange->{d,e}, PlotLabel->"Dupin Indicatrix at the  point"],
       Show[Graf3,PlotRange->{d,e},PlotLabel->"Dupin Indicatrix at the point"]]]


(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
DupinIndicatrixEquations[a_,b_,c_,d_]:=
Module[{}, Forma2=SecondFundamentalForm[a,b];
           Kuzelosecka=Forma2[[1,1]] (d[[1]])^2+2 Forma2[[1,2]] (d[[1]]) (d[[2]])+ Forma2[[2,2]](d[[2]])^2/.Thread[b->c];
           rovnice1=Kuzelosecka-1==0;
           rovnice2=Kuzelosecka+1==0;
          {rovnice1,rovnice2}
]


(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
DupinIndicatrixEquationsWithoutZero[a_,b_,c_,d_]:=
Module[{}, Forma2=SecondFundamentalForm[a,b];
           Kuzelosecka=Forma2[[1,1]] (d[[1]])^2+2 Forma2[[1,2]] (d[[1]]) (d[[2]])+ Forma2[[2,2]](d[[2]])^2/.Thread[b->c];
           rovnice1=Kuzelosecka-1;
           rovnice2=Kuzelosecka+1;
          {rovnice1,rovnice2}
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
GeneralDupinIndicatrixEquations[a_,b_,d_]:=
Module[{}, Forma2=SecondFundamentalForm[a,b];
           Kuzelosecka=Forma2[[1,1]] (d[[1]])^2+2 Forma2[[1,2]] (d[[1]]) (d[[2]])+ Forma2[[2,2]](d[[2]])^2;
           rovnice1=Kuzelosecka-1==0;
           rovnice2=Kuzelosecka+1==0;
          {rovnice1,rovnice2}
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
GeneralDupinIndicatrixEquationsWithoutZero[a_,b_,d_]:=
Module[{}, Forma2=SecondFundamentalForm[a,b];
           Kuzelosecka=Forma2[[1,1]] (d[[1]])^2+2 Forma2[[1,2]] (d[[1]]) (d[[2]])+ Forma2[[2,2]](d[[2]])^2;
           rovnice1=Kuzelosecka-1;
           rovnice2=Kuzelosecka+1;
          {rovnice1,rovnice2}
]


(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
ParametricPlane[a_,b1_,b2_,c_,d_]:=
Module[{},
    SecondForm=SecondFundamentalForm[a,{b1,b2}];
    EqualParametric=
      ContourPlot[SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2==0,
                  {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]}];
    
    result=
      If[
        ToString[Head[EqualParametric]]=="Graphics",
           Show[
              RegionPlot[ 
                 SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2<0,
                 {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]} ,
                 PlotStyle->{RGBColor[1,0,0]},
                 PlotRange->{{c[[1]],c[[2]]},{d[[1]],d[[2]]}}
                 ],
             RegionPlot[ 
                SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2> 0,
                {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]},
                 PlotStyle->{RGBColor[0,1,0]}
                ],
            RegionPlot[ 
                SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2==0,
                {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]},
                PlotStyle->{RGBColor[0,0,1]}
               ],
           ContourPlot[ 
                SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2==0,
                {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]} ,
                ContourStyle->{RGBColor[0,0,1]}
                ]],                
              (*ELSE*)
          Show[
            RegionPlot[ 
               SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2<0,
               {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]} ,
               PlotStyle->{RGBColor[1,0,0]},
               PlotRange->{{c[[1]],c[[2]]},{d[[1]],d[[2]]}}
               ],
           RegionPlot[ 
               SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2>0,
               {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]},
               PlotStyle->{RGBColor[0,1,0]}
              ],
           RegionPlot[ 
               SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2==0,
               {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]},
               PlotStyle->{RGBColor[0,0,1]}
              ]]
           ];
Show[result]]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
  
ParametricPlaneLegend[a_,b1_,b2_,c_,d_]:=
Module[{},
    SecondForm=SecondFundamentalForm[a,{b1,b2}];
    EqualParametric=
      ContourPlot[SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2==0,
                  {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]}
                 ];
    
    result=
      If[
        ToString[Head[EqualParametric]]=="Graphics",
          ShowLegend[
            Show[
              RegionPlot[ 
                 SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2<0,
                 {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]} ,
                 PlotStyle->{RGBColor[1,0,0]},
                 PlotRange->{{c[[1]],c[[2]]},{d[[1]],d[[2]]}}
                ],
             RegionPlot[ 
                SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2> 0,
                {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]},                
                PlotStyle->{RGBColor[0,1,0]}
                ],
            RegionPlot[ 
                SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2==0,
                {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]},                
                PlotStyle->{RGBColor[0,0,1]}
                ],
            ContourPlot[ 
                SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2==
                0, {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]},
                ContourStyle->{RGBColor[0,0,1]}
                ]],
                
                {{{RGBColor[1,0,0],"<0"},
                  {RGBColor[0,1,0],">0"},
                  {RGBColor[0,0,1],"=0"}},
                  LegendPosition->{1.5,0},
                  LegendLabel->"Second Fundamental Form",
                  LegendSize->{1.5,1}}],
        (*ELSE*)
        ShowLegend[
          Show[
            RegionPlot[ 
               SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2<0,
               {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]} ,
               PlotStyle->{RGBColor[1,0,0]},
               PlotRange->{{c[[1]],c[[2]]},{d[[1]],d[[2]]}}
               ],
            RegionPlot[ 
               SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2>0,
               {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]},
               PlotStyle->{RGBColor[0,1,0]}
               ],
            RegionPlot[ 
               SecondForm[[1,1]] SecondForm[[2,2]] - SecondForm[[1,2]]^2==0,
               {b1, c[[1]], c[[2]]}, {b2, d[[1]],d[[2]]},               
               PlotStyle->{RGBColor[0,0,1]}
               ]],
       
               {{{RGBColor[1,0,0],"< 0"},
                 {RGBColor[0,1,0],"> 0"},
                 {RGBColor[0,0,1],"= 0"}},
                  LegendSize->{1.5,1},
                  LegendLabel->"Second Fundamental Form",
                  LegendPosition->{1.5,0}}]];
Show[result]]


(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)

HessMatrix[p_,a_]:=
Module[{}, matice= { { D[p,{a[[1]],2}][[3]],D[p,a[[1]],a[[2]]][[3]] },
                     { D[p,a[[2]],a[[1]]][[3]], D[p,{a[[2]],2}][[3]] } };
           matice           
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
ConvexSurface[p_,a1_,a2_,b_,c_,d_]:=
Module[{},matice=HessMatrix[p,{a1,a2}];
         vysledek=If[ToString[InequalitySolve[matice[[1,1]]>0&&Det[matice]>0,{a1,a2}]]==ToString[False],
                    "convex domain does not exist",
                    RegionPlot[matice[[1,1]]>0&&Det[matice]>0,{a1,b[[1]],b[[2]]},{a2,c[[1]],c[[2]]}, 
                    PlotRange->{{b[[1]],b[[2]]},{c[[1]],c[[2]]}},PlotStyle->GrayLevel[d]]];
        If[ToString[Head[vysledek]]==ToString[Graphics],
           Show[vysledek],
           Print[vysledek]]
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
ConvexSurfaceInequality[p_,a_]:=
Module[{},matice=HessMatrix[p,a];
          vysledek=If[ToString[Reduce[matice[[1,1]]>0&&Det[matice]>0,a]]==ToString[False],
                     Print["convex domain does not exist"],
                     Reduce[matice[[1,1]]>0&&Det[matice]>0,a]];
         vysledek
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
ConcaveSurface[p_,a1_,a2_,b_,c_,d_]:=
Module[{},matice=HessMatrix[p,{a1,a2}];
         vysledek=If[ToString[InequalitySolve[matice[[1,1]]<0&&Det[matice]>0,a]]==ToString[False],
                    "concave domain does not exist",
                    RegionPlot[matice[[1,1]]<0&&Det[matice]>0,{a1,b[[1]],b[[2]]},{a2,c[[1]],c[[2]]}, 
                    PlotRange->{{b[[1]],b[[2]]},{c[[1]],c[[2]]}},PlotStyle->GrayLevel[d]]];
        If[ToString[Head[vysledek]]==ToString[Graphics],
           Show[vysledek],
           Print[vysledek]]]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
ConcaveSurfaceInequality[p_,a_]:=
Module[{},matice=HessMatrix[p,a];
          vysledek=If[ToString[InequalitySolve[matice[[1,1]]<0&&Det[matice]>0,a]]==ToString[False],
                   Print["concave domain does not exist"],
                   InequalitySolve[matice[[1,1]]<0&&Det[matice]>0,a]];
          vysledek
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
FirstCurvature[a_,b_]:=
Module[{},delka=Length[a];
         If[delka==2,
            new={a[[1]],a[[2]],0},
            new=a];
         D1=D[new,b]; D2=D[D1,b];
         vk1=Cross[D1,D2];vk3=NormOfVector[vk1]; vk2=NormOfVector[D1];
         krivost=vk3/vk2^3;
         krivost
      ]
  
(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
SecondCurvature[a_,b_]:=
Module[{},delka=Length[a];
          If[delka==2,
             {Print["Plane curve, second curvature will be zero"],new={a[[1]],a[[2]],0}},
             new=a];
          D1=D[new,b];D2=D[D1,b];D3=D[D2,b];
          Matice={D1,D2,D3};Determinant=Det[Matice];
          vs=Cross[D1,D2]; vv=NormOfVector[vs];
          krivost2=Determinant/vv^2;
          krivost2
      ]
(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
ConvexConcaveSurface:=
Module[]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
GaussCurvature[a_,b_]:=
Module[{},FFF=FirstFundamentalForm[a,b];
          SFF=SecondFundamentalForm[a,b];
          K=(SFF[[1,1]] SFF[[2,2]]-(SFF[[1,2]])^2)/(FFF[[1,1]] FFF[[2,2]]-(FFF[[1,2]])^2);
          FullSimplify[K]
       ]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
MiddleCurvature[a_,b_]:=
  Module[{},FFF=FirstFundamentalForm[a,b];
            SFF=SecondFundamentalForm[a,b];
            S=(FFF[[1,1]] SFF[[2,2]]-2 SFF[[1,2]] FFF[[1,2]]+FFF[[2,2]]SFF[[1,1]])/(2 (FFF[[1,1]] FFF[[2,2]]-(FFF[[1,2]])^2));
            FullSimplify[S]
        ]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
ExtremalMiddleCurvature[a_,b_]:=
Module[{}, krivost=MiddleCurvature[a,b];
           derivace1=D[krivost,b[[1]]];
           derivace2=D[krivost,b[[2]]];
           reseniJedna=FullSimplify[Reduce[derivace1==0,b\[Element]Reals]];
           reseniDva=FullSimplify[Reduce[derivace2==0,b\[Element]Reals]];
           reseni=FullSimplify[Reduce[reseniJedna\[And]reseniDva,b\[Element]Reals]];
           reseni
           ]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
FrenetTrihedron[a_,b_,c_,d_]:=
Module[{},delka=Length[a];
          If[delka==2,
             new={a[[1]],a[[2]],0},
             new=a];
          tecna=D1=D[new,b];
          VTecna=NormOfVector[tecna];
          Tecna=tecna/VTecna;D2=D[D1,b];
          binormala=Cross[D1,D2];
          VBinormala=NormOfVector[binormala];
          Binormala=binormala/VBinormala; 
          D3=D[D2,b];
          normala=Cross[D1,binormala]; 
          VNormala=NormOfVector[normala];
          Normala=normala/VNormala;
          trojhran=ListVectorFieldPlot3D[{{(new/.b->c),(Tecna/.b->c)},
                                          {(new/.b->c),(Normala/.b->c)},
                                          {(new/.b->c),(Binormala/.b->c)}},
                                          VectorHeads->True];
          KrivkaPlot= ParametricPlot3D[new,{b,d[[1]],d[[2]]}];
          Bod=Graphics3D[{PointSize[0.002],Point[new/.b->c]}];
          Show[trojhran,KrivkaPlot,Bod,PlotRange->All]
      ]
  
(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)  
MinimalFirstCurvature[a_,b_]:=
Module[{},krivost=FirstCurvature[a,b];          
          derivace=Simplify[D[krivost,b]];
          If[derivace==0,{Print["Constant curvature"], MinCislo=ReplaceAll[krivost,b->0],logicka=1,Goto[Konec]}];
          reseni=Expand[b/.Solve[derivace==0,b]];delka=Length[reseni];
          realne=Table[Null,{o,1,delka}];
          i=1;
          Table[If[Im[reseni[[j]]]==0,{realne[[i]]=reseni[[j]],i++}],{j,1,delka}];
          delkaReal=i-1;
          Hodnoty=Table[ReplaceAll[krivost,b->realne[[k]]],{k,1,delkaReal}];
          MaxCislo=Max[Table[N[Hodnoty[[s]]],{s,1,delkaReal}]];  
           logicka=2;
          Label[Konec];
          If[logicka==2,Print[MaxCislo],Print[MinCislo]];        
      ]  
      
(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)      
PointsOfMinimalFirstCurvature[a_,b_,c_]:=
Module[{},krivost=FirstCurvature[a,b];
          minKrivost=MinimalFirstCurvature[a,b];
          body=b/.Solve[krivost==MinimalFirstCurvature[a,b],b];
          delka=Length[body];
          delkaKrivka=Length[a];
          If[delkaKrivka==2,
             new={a[[1]],a[[2]],0},
             new=a];
          bodyPlot=Table[Graphics3D[{PointSize[0.02],Point[new/.b->body[[i]]]}],{i,1,delka}];
          KrivkaPlot=ParametricPlot3D[new,{b,c[[1]],c[[2]]}];
          Show[bodyPlot,KrivkaPlot,PlotRange->All];
body
       ]        
(*
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 ------------ GEOMETRY 2 --------------------------------------------------------------------------------------------------------------------------------------------------------
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)

(*
-------------------------------------------------------------------------------------------
------------- CONIC SECTION ---------------------------------------------------------------
-------------------------------------------------------------------------------------------
*)
(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
UnitGivenVector[a_]:=Module[{},b=a/NormOfVector[a];
b]
(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
MatrixOfConicSection[k_,a_]:=
Module[{},iksnadruhou=Coefficient[k,(a[[1]])^2];
          ypsilonnadruhou=Coefficient[k,(a[[2]])^2];
          iks=Coefficient[k,a[[1]]]; 
          ikspodruhe=Coefficient[iks,a[[2]]];
          ypsilon=Coefficient[k,a[[2]]];
          ypsilonpodruhe=Coefficient[ypsilon,a[[1]]];
          iksypsilon=Coefficient[k,a[[1]] a[[2]]];
          Iks=iks - ikspodruhe a[[2]];
          Ypsilon=ypsilon-ypsilonpodruhe a[[1]];
          nic = Simplify[k-(iksnadruhou a[[1]]^2 + ypsilonnadruhou a[[2]]^2
                            + Iks a[[1]] + Ypsilon a[[2]] + iksypsilon a[[1]] a[[2]])];
          Matice={{nic,Iks 1/2, Ypsilon 1/2},{Iks 1/2, iksnadruhou, iksypsilon 1/2},{Ypsilon 1/2, iksypsilon 1/2, ypsilonnadruhou}};      
      MatrixForm[Matice]
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
CoefficientsOfConicSection[k_,a_]:=
Module[{},iksnadruhou=Coefficient[k,(a[[1]])^2];
          ypsilonnadruhou=Coefficient[k,(a[[2]])^2];
          iks=Coefficient[k,a[[1]]]; 
          ikspodruhe=Coefficient[iks,a[[2]]];
          ypsilon=Coefficient[k,a[[2]]];
          ypsilonpodruhe=Coefficient[ypsilon,a[[1]]];
          iksypsilon=Coefficient[k,a[[1]] a[[2]]];
          Iks=iks - ikspodruhe a[[2]];
          Ypsilon=ypsilon-ypsilonpodruhe a[[1]];
          nic = Simplify[k-(iksnadruhou a[[1]]^2 + ypsilonnadruhou a[[2]]^2
                            + Iks a[[1]] + Ypsilon a[[2]] + iksypsilon a[[1]] a[[2]])];
          Matice={{nic,Iks 1/2, Ypsilon 1/2},{Iks 1/2, iksnadruhou, iksypsilon 1/2},{Ypsilon 1/2, iksypsilon 1/2, ypsilonnadruhou}};      
      Matice
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
CentreOfConicSectionDiscussion[k_,a_]:=
Module[{},koef=CoefficientsOfConicSection[k,a];
         SubmaticeDvaTri=Take[koef,{2,3},{1,3}];
         SubmaticeDvaDva=Take[koef,{2,3},{2,3}];
         HodnostDvaTri=MatrixRank[SubmaticeDvaTri];
         HodnostDvaDva=MatrixRank[SubmaticeDvaDva];
         If[HodnostDvaTri==HodnostDvaDva==2,
            stred="one centre", 
           If[HodnostDvaTri==HodnostDvaDva==1,
              If[koef[[2,2]]==0 \[And] koef[[2,3]]==0 \[And] koef[[2,1]]==0,
                 stred="the line of centres",
                 stred="the line of centres"
              ],
              If[HodnostDvaTri!=HodnostDvaDva,
                If[koef[[2,2]]==0 \[And] koef[2,3]==0,
                   stred="improper centre, it doesnt exist",
                   stred="improper centre, it doesnt exist"
                ]
              ]            
           ] 
         ];
         stred              
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
CentreOfConicSection[k_,a_]:=
Module[{},koef=CoefficientsOfConicSection[k,a];
         SubmaticeDvaTri=Take[koef,{2,3},{1,3}];
         SubmaticeDvaDva=Take[koef,{2,3},{2,3}];
         HodnostDvaTri=MatrixRank[SubmaticeDvaTri];
         HodnostDvaDva=MatrixRank[SubmaticeDvaDva];
         If[HodnostDvaTri==HodnostDvaDva==2,
            St=First[{a[[1]],a[[2]]}/.
                        Solve[{koef[[2,2]] a[[1]] + koef[[2,3]] a[[2]] == - koef[[2,1]],
                               koef[[3,2]] a[[1]] + koef[[3,3]] a[[2]] == - koef[[3,1]]},
                              {a[[1]],a[[2]]}]], 
           If[HodnostDvaTri==HodnostDvaDva==1,
              If[koef[[2,2]]==0 \[And] koef[[2,3]]==0 \[And] koef[[2,1]]==0,
                 St=koef[[3,2]] a[[1]] + koef[[3,3]] a[[2]] == - koef[[3,1]],
                 St=koef[[2,2]] a[[1]] + koef[[2,3]] a[[2]] == - koef[[2,1]]
              ],
              If[HodnostDvaTri!=HodnostDvaDva,
                If[koef[[2,2]]==0 \[And] koef[2,3]==0,
                   St={koef[[3,3]],-koef[[3,2]]},
                   St={koef[[2,3]],-koef[[2,2]]}
                ]
              ]            
           ] 
         ];
         Return[St]
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
PlotOfConicSection[k_,a1_,a2_,b_,c_,d_]:=
Module[{},
      Kuzelosecka=ContourPlot[k==0,{a1,b[[1]],b[[2]]},{a2,c[[1]],c[[2]]},AspectRatio->1/GoldenRatio,ContourStyle->{Hue[d]}];
      Show[Kuzelosecka,AspectRatio->Automatic]
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
AsymptoticDirectionOfConicSection[k_,a_]:=
Module[{},homogenizace=k/.{a[[1]]->x1/x0,a[[2]]->x2/x0};
          uprava1=Simplify[homogenizace x0 x0];
          uprava2=uprava1/.x0->0;
          If[Flatten[Solve[uprava2==0,{x1}]]!= {},
            {vysledek= Flatten[{x1}/.Solve[uprava2==0,x1]],smer={{vysledek[[1]],x2},{vysledek[[2]],x2}}/.x2->1},
            If[Flatten[Solve[uprava2==0,{x2}]]!={},{vysledek=Flatten[x2/.Solve[uprava2==0,x2]],smer={{vysledek[[1]],x2},{vysledek[[2]],x2}}/.x2->1},
               smer="The aymptitic direction does not exist."]
         ];
       smer
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
PlotOfAsymptoteOfConicSection[k_,a_,b_,c_]:=
Module[{}, stred=CentreOfConicSection[k,a];
           smer=AsymptoticDirectionOfConicSection[k,a];
           graf1=ParametricPlot[smer[[1]] t + stred,{t,b[[1]],b[[2]]},PlotStyle->Hue[c]];
           graf2=ParametricPlot[smer[[2]] t + stred,{t,b[[1]],b[[2]]},PlotStyle->Hue[c]];
           Show[graf1,graf2]
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
MainDirectionOfConicSection[k_,a_]:=
Module[{},Matice=CoefficientsOfConicSection[k,a];
          SubMatice=Take[Matice,{2,3},{2,3}];
          VlastniHodnoty=Eigenvectors[SubMatice];
          VlastniHodnoty
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
PlotOfMainDirectionOfConicSection[k_,a_,b_,c_]:=
Module[{},hsmer=MainDirectionOfConicSection[k,a];
          stred=CentreOfConicSection[k,a];
          graf1=ParametricPlot[hsmer[[1]] t+stred,{t,b[[1]],b[[2]]},PlotStyle->Hue[c]];
          graf2=ParametricPlot[hsmer[[2]] r+stred,{r,b[[1]],b[[2]]},PlotStyle->Hue[c]];
          Show[graf1,graf2,AspectRatio->Automatic]
]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
TransformationOfConicSection[k_,a_]:=
Module[{},vekProm={1,a[[1]],a[[2]]};
          MaticeC=CoefficientsOfConicSection[k,a];
          stred=CentreOfConicSection[k,a];
          hsmer=MainDirectionOfConicSection[k,a];
          JednHlSmer1=UnitGivenVector[hsmer[[1]]];
          JednHlSmer2=UnitGivenVector[hsmer[[2]]];
          A={{1,0,0},
             {stred[[1]], JednHlSmer1[[1]],JednHlSmer2[[1]]},
             {stred[[2]], JednHlSmer1[[2]],JednHlSmer2[[2]]}};
          MaticTransform=Transpose[A].MaticeC.A;
          kzsecka=vekProm.MaticTransform.vekProm;
          Simplify[kzsecka]
]
          
(*
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 ------------ ALGORITMUS (using conic section and differential geometry) --------------------------------------------------------------------------------------------------------
 --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)
EllipticPoints[a_,b_]:=
 Module[{},SFF=SecondFundamentalForm[a,b];
           Area=Reduce[SFF[[1,1]] SFF[[2,2]] -SFF[[1,2]]^2>0,b \[Element] Reals];
           If[ToString[Area]=="True",
              Conditions="all points are elliptic",
              If[ToString[Area]=="False",
                 Conditions="no points are elliptic",
                 Conditions=Area]];
        Conditions]    

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)

ParabolicPoints[a_,b_]:=
 Module[{},SFF=SecondFundamentalForm[a,b];
           Area=Reduce[SFF[[1,1]] SFF[[2,2]] -SFF[[1,2]]^2==0,b];
          If[ToString[Area]=="True",
             Conditions="all points are parabolic",
            If[ToString[Area]=="False",
               Conditions="no points are parabolic",
               Conditions=Area]];
        Conditions]    

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)

HyperbolicPoints[a_,b_]:=
 Module[{},SFF=SecondFundamentalForm[a,b];
           Area=Reduce[SFF[[1,1]] SFF[[2,2]] -SFF[[1,2]]^2<0,b];
           If[ToString[Area]=="True",
              Conditions="all points are hyperbolic",
              If[ToString[Area]=="False",
                 Conditions="no points are hyperbolic",
                 Conditions=Area]];
       Conditions]      

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)

ConvexDiscussionOfMainDirection[a_,b_,oblast_]:=
 Module[{},DI=GeneralDupinIndicatrixEquationsWithoutZero[a,b,{x,y}];
           HlSm=MainDirectionOfConicSection[DI[[1]],{x,y}];
           ObecnePlocha[m_,n_]:= ReplaceAll[{a[[1]],a[[2]],a[[3]]},{b[[1]]->m,b[[2]]->n}];
           HlSm1[v_,w_]:=ReplaceAll[HlSm[[1]],{b[[1]]->v,b[[2]]->w}];
           HlSm2[v_,w_]:=ReplaceAll[HlSm[[2]],{b[[1]]->v,b[[2]]->w}];
           KrivkaHlSm1[t_]:=ObecnePlocha[b[[1]]+HlSm1[b[[1]],b[[2]]][[1]] t, b[[2]]+HlSm1[b[[1]],b[[2]]][[2]] t];
           KrivkaHlSm2[t_]:=ObecnePlocha[b[[1]]+HlSm2[b[[1]],b[[2]]][[1]] t, b[[2]]+HlSm2[b[[1]],b[[2]]][[2]] t];
           DrDe1=D[KrivkaHlSm1[q],{q,2}];
           DrDe2=D[KrivkaHlSm2[q],{q,2}];
           VelDrDe1=ReplaceAll[DrDe1[[3]],q->0];
           VelDrDe2=ReplaceAll[DrDe2[[3]],q->0];
           PrvniNerovnost=Reduce[oblast&&VelDrDe1>0,b];
           DruhaNerovnost=Reduce[oblast&&VelDrDe2>0,b]; 
          {"Direction " ,HlSm1[b[[1]],b[[2]]]," is convex at the domain ",PrvniNerovnost, "and the Direction", HlSm2[b[[1]],b[[2]]], "is convex
           at the domain "DruhaNerovnost}
        ]

(*
--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
*)

IntersectionWithHyperbola[c_,a_,h_,variables_]:=
  Module[{},DI=GeneralDupinIndicatrixEquationsWithoutZero[c,a,variables];
            PrimkaHlSm=-h[[2]] variables[[1]]+h[[1]] variables[[2]];
            R1=Solve[DI[[1]]==PrimkaHlSm==0,variables];
            R2=Solve[DI[[2]]==PrimkaHlSm==0,variables];
           {R1,"is general intersection with  Dupin indicatrix ",DI[[1]],"and",
            R2,"is general intersection with Dupin indicatrix ",DI[[2]]}
        ]
      
End[]

EndPackage[]

Print["{Offsets, Differential Geometry, Geometry - ConicSection, Parts of MillingAlgorithm}"]



